@@ -8,6 +8,7 @@
 ##parameters=images=0, folders=0, subimages=0
 
 from Products.CMFPlone.utils import base_hasattr
+from Products.CMFPlone.utils import getToolByName
 
 result = {}
 
@@ -15,6 +16,19 @@ if images:
     result['images'] = context.getFolderContents({
         'portal_type': ('Image',)
     }, full_objects=True)
+
+    if context.getShow_images_from_main_lang():
+        ltool = getToolByName(context, 'portal_languages')
+        preflang = ltool.getPreferredLanguage()
+        deflang = ltool.getDefaultLanguage()
+
+        if preflang != deflang and hasattr(context, 'getTranslation'):
+            deflangcontext = context.getTranslation(deflang)
+            deflangcontent = deflangcontext.getFolderContents({
+                'portal_type': ('Image',),
+                'Language' : (deflang, '', None),
+            }, full_objects=True)
+            result['images'] = result['images'] + deflangcontent
 if folders:
     # We don't need the full objects for the folders
     result['folders'] = context.getFolderContents({
@@ -28,7 +42,7 @@ if subimages:
         path = '/'.join(context.getPhysicalPath())
     # Explicitly set path to remove default depth
     result['subimages'] = context.getFolderContents({
-        'Type':('Image',), 
+        'Type':('Image',),
         'path':path
     })
 
